/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM flockILuceneListener.idl
 */

#ifndef __gen_flockILuceneListener_h__
#define __gen_flockILuceneListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsISimpleEnumerator_h__
#include "nsISimpleEnumerator.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    flockILuceneResult */
#define FLOCKILUCENERESULT_IID_STR "625248a0-9d3f-4060-9585-a765b8242df3"

#define FLOCKILUCENERESULT_IID \
  {0x625248a0, 0x9d3f, 0x4060, \
    { 0x95, 0x85, 0xa7, 0x65, 0xb8, 0x24, 0x2d, 0xf3 }}

/**
 * flockILuceneResult
 *
 * This is an interface that describes a result from a Lucene query.
 */
class NS_NO_VTABLE flockILuceneResult : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(FLOCKILUCENERESULT_IID)

  /* readonly attribute string URI; */
  NS_IMETHOD GetURI(char * *aURI) = 0;

  /* readonly attribute string type; */
  NS_IMETHOD GetType(char * *aType) = 0;

  /* readonly attribute wstring URL; */
  NS_IMETHOD GetURL(PRUnichar * *aURL) = 0;

  /* readonly attribute wstring title; */
  NS_IMETHOD GetTitle(PRUnichar * *aTitle) = 0;

  /* readonly attribute double score; */
  NS_IMETHOD GetScore(double *aScore) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKILUCENERESULT \
  NS_IMETHOD GetURI(char * *aURI); \
  NS_IMETHOD GetType(char * *aType); \
  NS_IMETHOD GetURL(PRUnichar * *aURL); \
  NS_IMETHOD GetTitle(PRUnichar * *aTitle); \
  NS_IMETHOD GetScore(double *aScore); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKILUCENERESULT(_to) \
  NS_IMETHOD GetURI(char * *aURI) { return _to GetURI(aURI); } \
  NS_IMETHOD GetType(char * *aType) { return _to GetType(aType); } \
  NS_IMETHOD GetURL(PRUnichar * *aURL) { return _to GetURL(aURL); } \
  NS_IMETHOD GetTitle(PRUnichar * *aTitle) { return _to GetTitle(aTitle); } \
  NS_IMETHOD GetScore(double *aScore) { return _to GetScore(aScore); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKILUCENERESULT(_to) \
  NS_IMETHOD GetURI(char * *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetURI(aURI); } \
  NS_IMETHOD GetType(char * *aType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetType(aType); } \
  NS_IMETHOD GetURL(PRUnichar * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetURL(aURL); } \
  NS_IMETHOD GetTitle(PRUnichar * *aTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTitle(aTitle); } \
  NS_IMETHOD GetScore(double *aScore) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetScore(aScore); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockILuceneResult
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKILUCENERESULT

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockILuceneResult)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* readonly attribute string URI; */
NS_IMETHODIMP _MYCLASS_::GetURI(char * *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string type; */
NS_IMETHODIMP _MYCLASS_::GetType(char * *aType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute wstring URL; */
NS_IMETHODIMP _MYCLASS_::GetURL(PRUnichar * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute wstring title; */
NS_IMETHODIMP _MYCLASS_::GetTitle(PRUnichar * *aTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute double score; */
NS_IMETHODIMP _MYCLASS_::GetScore(double *aScore)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockILuceneListener */
#define FLOCKILUCENELISTENER_IID_STR "288ac5a5-4671-4ddf-8dff-e3a98a5385ba"

#define FLOCKILUCENELISTENER_IID \
  {0x288ac5a5, 0x4671, 0x4ddf, \
    { 0x8d, 0xff, 0xe3, 0xa9, 0x8a, 0x53, 0x85, 0xba }}

/**
 * flockILuceneListener
 * 
 * This is a listener interface used by flockILucene.
 */
class NS_NO_VTABLE flockILuceneListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(FLOCKILUCENELISTENER_IID)

  /**
   * Called on completetion of an associated flockILucene search call.
   *
   * @param aNumResults
   *        the number of search results being returned
   * @param aEnumerator
   *        an enumerator of flockILuceneResults
   */
  /* void onSearchComplete (in unsigned long aNumResults, in nsISimpleEnumerator aEnumerator); */
  NS_IMETHOD OnSearchComplete(PRUint32 aNumResults, nsISimpleEnumerator *aEnumerator) = 0;

  /**
   * Called on completetion of an associated flockILucene addDocument call.
   *
   * @param aURI
   *        the URI of the document that has been added
   */
  /* void onAddDocumentComplete (in string aURI); */
  NS_IMETHOD OnAddDocumentComplete(const char *aURI) = 0;

  /**
   * Called on completetion of an associated flockILucene deleteDocument call.
   *
   * @param aURI
   *        the URI of the document that has been deleted
   */
  /* void onDeleteDocumentComplete (in string aURI); */
  NS_IMETHOD OnDeleteDocumentComplete(const char *aURI) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKILUCENELISTENER \
  NS_IMETHOD OnSearchComplete(PRUint32 aNumResults, nsISimpleEnumerator *aEnumerator); \
  NS_IMETHOD OnAddDocumentComplete(const char *aURI); \
  NS_IMETHOD OnDeleteDocumentComplete(const char *aURI); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKILUCENELISTENER(_to) \
  NS_IMETHOD OnSearchComplete(PRUint32 aNumResults, nsISimpleEnumerator *aEnumerator) { return _to OnSearchComplete(aNumResults, aEnumerator); } \
  NS_IMETHOD OnAddDocumentComplete(const char *aURI) { return _to OnAddDocumentComplete(aURI); } \
  NS_IMETHOD OnDeleteDocumentComplete(const char *aURI) { return _to OnDeleteDocumentComplete(aURI); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKILUCENELISTENER(_to) \
  NS_IMETHOD OnSearchComplete(PRUint32 aNumResults, nsISimpleEnumerator *aEnumerator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnSearchComplete(aNumResults, aEnumerator); } \
  NS_IMETHOD OnAddDocumentComplete(const char *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnAddDocumentComplete(aURI); } \
  NS_IMETHOD OnDeleteDocumentComplete(const char *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnDeleteDocumentComplete(aURI); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockILuceneListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKILUCENELISTENER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockILuceneListener)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void onSearchComplete (in unsigned long aNumResults, in nsISimpleEnumerator aEnumerator); */
NS_IMETHODIMP _MYCLASS_::OnSearchComplete(PRUint32 aNumResults, nsISimpleEnumerator *aEnumerator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onAddDocumentComplete (in string aURI); */
NS_IMETHODIMP _MYCLASS_::OnAddDocumentComplete(const char *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onDeleteDocumentComplete (in string aURI); */
NS_IMETHODIMP _MYCLASS_::OnDeleteDocumentComplete(const char *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_flockILuceneListener_h__ */
